@@ -259,7 +259,24 @@ Changelog
 		to ascii encoding, which bombs out if you use any extended
 		characters in the template, or variables passed to the template.
 		
-		Patches are welcome!
+	Version 2.0.1
+	-------------
+		 - Applied patch submitted by Jason Chu to allow overriding of
+		   the Sender and Return-Path headers.
+		 - Applied patch submitted by Jason Chu to correct the MIME
+		   type of dual text & html messages with attachments.
+
+	Version 2.0.2
+	-------------
+		 - Added a generic ControllerMessage which uses the output of
+		   any function or method that returns HTML.
+		 - Changed the behaviour of the attach and embed methods to
+		   pull content from an existing file-like object or open an
+		   on-disk file.
+		 - Corrected a conditional testing for the presense of
+		   smptfrom as a message property.  Thanks James!
+		
+		More patches are welcome!
 
 @var _queue: After TurboGears startup within an application which has
             enabled TurboMail, I{queue} is an instance of a MailPool
