@@ -141,24 +141,31 @@ class Message(object):
 		self.smtpfrom = None
 		
 		for i, j in kw.iteritems():
-			if i in self.__dict__:
-				self.__dict__[i] = j
+			assert i in self.__dict__, "Unknown attribute: '%s'" % i
+			self.__dict__[i] = j
 			
 	def attach(self, file, name=None):
 		"""Attach an on-disk file to this message.
 		
-		@param file: The path to the file you wish to attach.
-		@type file: string
+		@param file: The path to the file you wish to attach, or an
+		             instance of a file-like object.
 		
 		@param name: You can optionally override the filename of the
 		             attached file.  This name will appear in the
-		             recipient's mail viewer.  B{Optional.}
+		             recipient's mail viewer.  B{Optional if passing
+		             an on-disk path.  Required if passing a file-like
+		             object.}
 		@type name: string
 		"""
 		
 		part = MIMEBase('application', "octet-stream")
 
-		fp = open(file, "rb")
+		if isinstance(file, (str, unicode)):
+			fp = open(file, "rb")
+		else:
+			assert name is not None, "If attaching a file-like object, you must pass a custom filename."
+			fp = file
+		
 		part.set_payload(fp.read())
 		Encoders.encode_base64(part)
 
@@ -171,16 +178,25 @@ class Message(object):
 		
 		This method should only be used to embed images.
 		
-		@param file: The path to the file you wish to attach.
-		@type file: string
+		@param file: The path to the file you wish to attach, or an
+		             instance of a file-like object.
 		
-		@param name: The CID name to use for the embedded object.
+		@param name: You can optionally override the filename of the
+		             attached file.  This name will appear in the
+		             recipient's mail viewer.  B{Optional if passing
+		             an on-disk path.  Required if passing a file-like
+		             object.}
 		@type name: string
 		"""
 		
 		from email.MIMEImage import MIMEImage
 		
-		fp = open(file, 'rb')
+		if isinstance(file, (str, unicode)):
+			fp = open(file, "rb")
+		else:
+			assert name is not None, "If embedding a file-like object, you must pass a custom filename."
+			fp = file
+
 		part = MIMEImage(fp.read())
 		fp.close()
 		
@@ -343,7 +359,7 @@ class Message(object):
 
 
 class KIDMessage(Message):
-	"""A template which accepts a named template with arguments.
+	"""A message that accepts a named template with arguments.
 	
 	Example usage::
 	
@@ -393,3 +409,57 @@ class KIDMessage(Message):
 		self.rich = turbogears.view.engines.get('kid').render(data, template=self._template)
 		
 		return super(KIDMessage, self)._process()
+
+class ControllerMessage(Message):
+	"""A message that accepts a callable and arguments.
+
+	Example usage::
+
+		import turbomail
+		message = turbomail.ControllerMessage(
+				"from@host.com",
+				"to@host.com",
+				"Subject",
+				controller.method,
+				dict()
+			)
+
+	Feel free to set a message.plain content as the controller only
+	returns HTML.  If you wish to hand-produce content, use the
+	Message class.
+	
+	This class can likely be improved to automatically generate the
+	plain text content from processing the HTML, calling two methods,
+	or calling a single method with special arguments.  Needs
+	discussion.
+	"""
+
+	def __init__(self, sender, recipient, subject, method, variables={}, **kw):
+		"""Store the additonal template and variable information.
+
+		@param method: Any callable that returns HTML; usually an
+		               exposed controller method.
+		@type method: callable
+
+		@param variables: A dictionary containing named variables to
+		                  pass to the method.
+		@type variables: dict
+		"""
+
+		self._method = method
+		self._variables = variables
+
+		super(ControllerMessage, self).__init__(sender, recipient, subject, **kw)
+
+	def _process(self):
+		"""Automatically generate the rich text content."""
+
+		data = dict(sender=self.sender, recipient=self.recipient, subject=self.subject)
+
+		for (i, j) in self._variables.iteritems():
+			if callable(j): data[i] = j()
+			else: data[i] = j
+
+		self.rich = self._method(**data)
+
+		return super(ControllerMessage, self)._process()
